# -*- encoding: UTF-8 -*-

dStrings = {
    "fr": {
            "title": u"Orthographe française",
            "choose": u"Choisissez un dictionnaire",
            "select": u"Utiliser ce dictionnaire",

            "classique": u"“Classique” (recommandé)",
            "reforme1990": u"“Réforme 1990”",
            "toutesvariantes": u"“Toutes variantes”",

            "descClassic": u"Ce dictionnaire propose l’orthographe telle qu’elle est écrite aujourd’hui le plus couramment. Toutefois, ont été intégrées quelques graphies acceptées par la réforme principalement pour des raisons de cohérence. Il s’agit de graphies rectifiant des erreurs ou des oublis dans les réformes précédentes.",
            "descReform": u"Avec ce dictionnaire, seule l’orthographe réformée est reconnue. Attendu que bon nombre de graphies réformées sont considérées comme erronées par beaucoup, ce dictionnaire est déconseillé. Les graphies passées dans l’usage sont déjà incluses dans le dictionnaire “Classique”.",
            "descAllvar": u"Ce dictionnaire contient les variantes graphiques classiques et “réformées”. Ce dictionnaire est déconseillé à ceux qui ne connaissent pas très bien la langue française.",

            "restart": u"Le changement ne sera effectif qu’après le redémarrage du logiciel.",
            "error": u"Erreur : impossible de savoir quel dictionnaire est actif."
          },
    "en": {
            "title": u"French spelling",
            "choose": u"Choose a dictionary",
            "select": u"Use this dictionary",

            "classique": u"“Classic” (recommended)",
            "reforme1990": u"“Reform 1990”",
            "toutesvariantes": u"“All variants”",

            "descClassic": u"This dictionary offers the French spelling as it is written nowadays most commonly. However, some of the spellings accepted by the reform have been incorporated mainly for reasons of coherence. These are spellings that rectify errors or omissions in previous reforms.",
            "descReform": u"With this dictionary, only the reformed spelling is recognized. As many of reformed spellings are considered erronous by many people, this dictionary is unadvised. Reformed spellings commonly used are already included in the “Classic” dictionary.",
            "descAllvar": u"This dictionary contains all spelling variants, classical and reformed. This dictionary is unadvised for those who don’t know very well the French language.",

            "restart": u"The modification will be effective only after restarting the software.",
            "error": u"Error: enable to retrieve information about the current dictionary."
          }
}


